@@ -2,9 +2,10 @@
 #define __BOARDGAMETEST_H__
 
 #include <cppunit/extensions/HelperMacros.h>
+#include <iostream>
 
-template<typename GAMECLASS> 
-class BoardGameTest : public CppUnit::TestFixture 
+template<class GAMECLASS> 
+class BoardGameTest : public CPPUNIT_NS::TestFixture 
 {
   CPPUNIT_TEST_SUITE( BoardGameTest );
   CPPUNIT_TEST( testReset );
